from __future__ import annotations

from PIL import Image 
import os

from path import Path

from typing import TYPE_CHECKING

import config

if TYPE_CHECKING:
    from page import Page 
    from album import Album

class Picture():
    def __init__(self, picture_path: Path, page = None, raw: Path|None = None, is_repertoried: bool = True):
        self._large: Path = picture_path
        self._small: Path = Path(picture_path.get_absolute_path()[:-4] + "_small.jpg")
        self._thumb: Path = Path(picture_path.get_absolute_path()[:-4] + "_thumb.jpg")
        self._profile_file: Path = Path(picture_path.get_absolute_path() + ".out.pp3")
        self._albums_file: Path = Path(picture_path.get_absolute_path()[:-4] + "_albums.txt")
        self._raw: Path|None = raw
        self._page: Page = page
        self._albums_name: list[str] = []
        if self._albums_file.exist():
            with open(self._albums_file.get_absolute_path(), "r+") as f:
                albums_name: list[str] = f.read()
                if (len(albums_name)):
                    self._albums_name += albums_name.split("\n")
        else:
            self._albums_file.touch()
        if (config.CREATE_GENERAL_ALBUM):
            self._albums_name.append("general")
        self._is_reperoried: bool = is_repertoried
        self.get_small()
        self.get_thumb()

    def get_page(self):
        return self._page

    def get_albums_name(self):
        return self._albums_name

    def get_small(self):
        if not self._small.exist():
            self.gen_small()
        return self._small
    
    def get_thumb(self):
        if not self._thumb.exist():
            self.gen_thumb()
        return self._thumb
    
    def get_large(self):
        return self._large
    
    def get_profile_file(self):
        return self._profile_file

    def gen_thumb(self):
        im = Image.open(self._large.get_absolute_path())
        im.thumbnail((500,500))
        im.save(self._thumb.get_absolute_path(), "JPEG")

    def gen_small(self):
        im = Image.open(self._large.get_absolute_path()).convert("RGB")
        im.save(self._small.get_absolute_path(), quality=95, optimize=True)

        